package com.sun.tools.javap.resources;

public final class version extends java.util.ListResourceBundle {
    protected final Object[][] getContents() {
        return new Object[][] {
            { "full", "1.8.0_242-b06" },
            { "jdk", "1.8.0_242" },
            { "release", "1.8.0_242" },
        };
    }
}
